@@ -325,7 +325,7 @@ class WebsocketSession(Session):
         # kicks ourself out
         self.onClose()
 
-    def onClose(self):
+    def onClose(self,request=None,content=None):        
         pass
 
     def __websocket_constructframe(self, data: WebsocketFrame) -> bytearray:
